@@ -1,5 +1,3 @@
-context("Output html tables in html_document .Rmd files")
-
 # write_in_tmpfile_for_cran() <- FALSE
 
 test_that(
@@ -15,3 +13,12 @@ test_that(
       "character"
     )
   })
+
+test_that("Outputformat html produces no errors",{
+  expect_error(capture_output(descr(
+    iris,
+    "Species",
+    group_labels = list(setosa = "My custom group label"),
+    var_options = list(Sepal.Length = list(label = "My custom variable label"))
+  ) %>% print(print_format="html", silent=FALSE)), NA)
+})
